;; lang/matlab/tables.scm

;; Copyright (C) 2015 Matthew R. Wette
;; 
;; This software is covered by the GNU GENERAL PUBLIC LICENCE, Version 3,
;; or any later version published by the Free Software Foundation.  See the
;; file COPYING included with the this distribution.

(define len-v
  #(1 1 1 1 2 4 3 2 0 2 2 1 1 2 10 9 8 7 6 5 1 3 1 2 1 1 1 5 4 8 9 8 6 9 8 6
    9 6 2 3 1 3 1 4 1 1 1 2 4 5 0 5 1 1 3 3 1 3 1 3 1 3 1 3 3 1 3 3 3 3 1 3 3
    1 3 3 3 3 3 3 3 3 1 2 2 2 1 4 2 2 1 1 1 3 2 3 1 3 1 1 1 3 1 2 2 3 1 1 1 1
    1 1 1 1))

(define pat-v
  #(((5 . 1) (40 . 2) (6 . 3) (47 . 4) (31 . 5) (32 . 6) (46 . 7) (1 . 8) (
    65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13) (39 . 14) (45 . 15) (70 . 
    16) (75 . 17) (74 . 18) (79 . 19) (82 . 20) (72 . 21) (83 . 22) (73 . 23) 
    (84 . 24) (85 . 25) (86 . 26) (87 . 27)) ((42 . -109) (43 . -109) (47 . 
    -109) (6 . -109) (40 . -109) (5 . -109) (28 . -109) (27 . -109) (26 . -109
    ) (25 . -109) (24 . -109) (20 . -109) (21 . -109) (22 . -109) (23 . -109) 
    (19 . -109) (18 . -109) (10 . -109) (11 . -109) (12 . -109) (13 . -109) (
    14 . -109) (15 . -109) (16 . -109) (17 . -109) (7 . -109) (8 . -109) (44 
    . -109) (41 . -109)) ((45 . -108) (39 . -108) (38 . -108) (37 . -108) (35 
    . -108) (33 . -108) (32 . -108) (31 . -108) (5 . -108) (47 . -108) (6 . 
    -108) (40 . -108) (1 . -108) (48 . -108) (34 . -108) (29 . -108) (36 . 
    -108) (30 . -108) (49 . -108) (46 . -108)) ((45 . -107) (39 . -107) (38 . 
    -107) (37 . -107) (35 . -107) (33 . -107) (32 . -107) (31 . -107) (5 . 
    -107) (47 . -107) (6 . -107) (40 . -107) (1 . -107) (48 . -107) (34 . -107
    ) (29 . -107) (36 . -107) (30 . -107) (49 . -107) (46 . -107)) ((45 . -106
    ) (39 . -106) (38 . -106) (37 . -106) (35 . -106) (33 . -106) (32 . -106) 
    (31 . -106) (5 . -106) (47 . -106) (6 . -106) (40 . -106) (1 . -106) (48 
    . -106) (34 . -106) (29 . -106) (36 . -106) (30 . -106) (49 . -106) (46 . 
    -106)) ((5 . -45)) ((5 . -44)) ((45 . 67) (5 . 1) (75 . 68)) ((1 . -113) (
    40 . -113) (6 . -113) (47 . -113) (5 . -113) (31 . -113) (32 . -113) (33 
    . -113) (35 . -113) (37 . -113) (38 . -113) (39 . -113) (45 . -113) (48 . 
    -113) (36 . -113) (30 . -113) (49 . -113) (46 . -113) (29 . -113) (34 . 
    -113)) ((5 . 1) (75 . 65) (64 . 66)) ((40 . 2) (6 . 3) (47 . 4) (74 . 64))
    ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 
    47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (
    58 . 55) (59 . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60) (69 . 63)) ((2 
    . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (
    75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 
    55) (59 . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60) (69 . 62)) ((2 . 41)
    (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 
    48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 55) (
    59 . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60) (69 . 61)) ((5 . 1) (75 
    . 40)) ((5 . 1) (75 . 37) (70 . 38) (68 . 39)) ((43 . 36)) ((42 . 35) (43 
    . -42)) ((1 . -26) (40 . -26) (6 . -26) (47 . -26) (5 . -26) (31 . -26) (
    32 . -26) (33 . -26) (35 . -26) (37 . -26) (38 . -26) (39 . -26) (45 . -26
    ) (48 . -26) (36 . -26) (30 . -26) (49 . -26) (46 . -26) (29 . -26) (34 . 
    -26)) ((1 . 8) (72 . 33) (78 . 34) (48 . -11) (40 . -11) (6 . -11) (47 . 
    -11) (5 . -11) (31 . -11) (32 . -11) (33 . -11) (35 . -11) (37 . -11) (38 
    . -11) (39 . -11) (45 . -11) (46 . -11) (49 . -11)) ((45 . -25) (39 . -25)
    (38 . -25) (37 . -25) (35 . -25) (33 . -25) (32 . -25) (31 . -25) (5 . 
    -25) (47 . -25) (6 . -25) (40 . -25) (1 . -25) (48 . -25) (36 . -25) (30 
    . -25) (49 . -25) (46 . -25) (29 . -25) (34 . -25)) ((45 . -24) (39 . -24)
    (38 . -24) (37 . -24) (35 . -24) (33 . -24) (32 . -24) (31 . -24) (5 . 
    -24) (47 . -24) (6 . -24) (40 . -24) (1 . -24) (48 . -24) (36 . -24) (30 
    . -24) (49 . -24) (46 . -24) (29 . -24) (34 . -24)) ((5 . 1) (40 . 2) (6 
    . 3) (47 . 4) (31 . 5) (32 . 6) (65 . 9) (33 . 10) (35 . 11) (37 . 12) (38
    . 13) (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 30) (48 . 
    31) (81 . 32) (49 . -8) (46 . -8)) ((1 . -22) (40 . -22) (6 . -22) (47 . 
    -22) (5 . -22) (31 . -22) (32 . -22) (33 . -22) (35 . -22) (37 . -22) (38 
    . -22) (39 . -22) (45 . -22) (48 . -22) (36 . -22) (30 . -22) (49 . -22) (
    46 . -22) (29 . -22) (34 . -22)) ((46 . -3) (49 . -3)) ((46 . 7) (79 . 19)
    (83 . 22) (84 . 29) (49 . -2)) ((5 . 1) (40 . 2) (6 . 3) (47 . 4) (31 . 5
    ) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13) (39 . 
    14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 20) (72 . 21) (73 . 28) 
    (49 . -1)) ((49 . 0)) ((1 . -23) (40 . -23) (6 . -23) (47 . -23) (5 . -23)
    (31 . -23) (32 . -23) (33 . -23) (35 . -23) (37 . -23) (38 . -23) (39 . 
    -23) (45 . -23) (49 . -23) (48 . -23) (46 . -23) (36 . -23) (30 . -23) (29
    . -23) (34 . -23)) ((46 . -4) (49 . -4)) ((48 . 31) (81 . 120) (5 . 1) (
    40 . 2) (6 . 3) (47 . 4) (31 . 5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 
    . 11) (37 . 12) (38 . 13) (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18
    ) (82 . 20) (72 . 21) (73 . 23) (86 . 121) (49 . -8) (46 . -8)) ((40 . 2) 
    (6 . 3) (47 . 4) (74 . 118) (80 . 119)) ((46 . -7) (49 . -7)) ((47 . 117))
    ((1 . 8) (72 . 116) (48 . -10) (40 . -10) (6 . -10) (47 . -10) (5 . -10) 
    (31 . -10) (32 . -10) (33 . -10) (35 . -10) (37 . -10) (38 . -10) (39 . 
    -10) (45 . -10) (46 . -10) (49 . -10)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1)
    (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 
    . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 55) (59 . 56) (60 . 57) (61 . 58
    ) (62 . 59) (63 . 60) (28 . 113) (69 . 114) (71 . 115)) ((2 . 41) (3 . 42)
    (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 
    49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 55) (59 . 56) (
    60 . 57) (61 . 58) (62 . 59) (63 . 60) (69 . 112)) ((42 . 111) (44 . -42) 
    (40 . -42)) ((44 . -40) (40 . -40)) ((40 . 109) (44 . 110)) ((43 . 108)) (
    (40 . -112) (6 . -112) (47 . -112) (28 . -112) (27 . -112) (26 . -112) (25
    . -112) (24 . -112) (20 . -112) (21 . -112) (22 . -112) (23 . -112) (19 
    . -112) (18 . -112) (10 . -112) (11 . -112) (12 . -112) (13 . -112) (14 . 
    -112) (15 . -112) (16 . -112) (17 . -112) (7 . -112) (8 . -112) (41 . -112
    ) (44 . -112)) ((40 . -111) (6 . -111) (47 . -111) (28 . -111) (27 . -111)
    (26 . -111) (25 . -111) (24 . -111) (20 . -111) (21 . -111) (22 . -111) (
    23 . -111) (19 . -111) (18 . -111) (10 . -111) (11 . -111) (12 . -111) (13
    . -111) (14 . -111) (15 . -111) (16 . -111) (17 . -111) (7 . -111) (8 . 
    -111) (41 . -111) (44 . -111)) ((40 . -110) (6 . -110) (47 . -110) (28 . 
    -110) (27 . -110) (26 . -110) (25 . -110) (24 . -110) (20 . -110) (21 . 
    -110) (22 . -110) (23 . -110) (19 . -110) (18 . -110) (10 . -110) (11 . 
    -110) (12 . -110) (13 . -110) (14 . -110) (15 . -110) (16 . -110) (17 . 
    -110) (7 . -110) (8 . -110) (41 . -110) (44 . -110)) ((44 . 104) (2 . 41) 
    (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48
    ) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 55) (59
    . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60) (69 . 105) (51 . 106) (52 
    . 107)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) 
    (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 
    . 54) (58 . 55) (59 . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60) (69 . 
    103)) ((47 . -92) (6 . -92) (40 . -92) (8 . -92) (7 . -92) (17 . -92) (16 
    . -92) (15 . -92) (14 . -92) (13 . -92) (12 . -92) (11 . -92) (10 . -92) (
    18 . -92) (19 . -92) (23 . -92) (22 . -92) (21 . -92) (20 . -92) (24 . -92
    ) (25 . -92) (26 . -92) (27 . -92) (28 . -92) (41 . -92) (44 . -92)) ((47 
    . -91) (6 . -91) (40 . -91) (8 . -91) (7 . -91) (17 . -91) (16 . -91) (15 
    . -91) (14 . -91) (13 . -91) (12 . -91) (11 . -91) (10 . -91) (18 . -91) (
    19 . -91) (23 . -91) (22 . -91) (21 . -91) (20 . -91) (24 . -91) (25 . -91
    ) (26 . -91) (27 . -91) (28 . -91) (41 . -91) (44 . -91)) ((42 . 102) (47 
    . -90) (6 . -90) (40 . -90) (8 . -90) (7 . -90) (17 . -90) (16 . -90) (15 
    . -90) (14 . -90) (13 . -90) (12 . -90) (11 . -90) (10 . -90) (18 . -90) (
    19 . -90) (23 . -90) (22 . -90) (21 . -90) (20 . -90) (24 . -90) (25 . -90
    ) (26 . -90) (27 . -90) (28 . -90) (41 . -90) (44 . -90)) ((40 . -86) (6 
    . -86) (47 . -86) (28 . -86) (27 . -86) (26 . -86) (25 . -86) (24 . -86) (
    20 . -86) (21 . -86) (22 . -86) (23 . -86) (19 . -86) (18 . -86) (10 . -86
    ) (11 . -86) (12 . -86) (13 . -86) (14 . -86) (15 . -86) (16 . -86) (17 . 
    -86) (7 . -86) (8 . -86) (41 . -86) (44 . -86)) ((2 . 41) (3 . 42) (4 . 43
    ) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (56 
    . 101)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) 
    (54 . 47) (75 . 48) (55 . 49) (56 . 100)) ((2 . 41) (3 . 42) (4 . 43) (5 
    . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (56 . 99)
    ) ((8 . 97) (7 . 98) (47 . -82) (6 . -82) (40 . -82) (17 . -82) (16 . -82)
    (15 . -82) (14 . -82) (13 . -82) (12 . -82) (11 . -82) (10 . -82) (18 . 
    -82) (19 . -82) (23 . -82) (22 . -82) (21 . -82) (20 . -82) (24 . -82) (25
    . -82) (26 . -82) (27 . -82) (28 . -82) (41 . -82) (44 . -82)) ((40 . -73
    ) (6 . -73) (47 . -73) (28 . -73) (27 . -73) (26 . -73) (25 . -73) (24 . 
    -73) (20 . -73) (21 . -73) (22 . -73) (23 . -73) (19 . -73) (18 . -73) (10
    . -73) (11 . -73) (12 . -73) (13 . -73) (14 . -73) (15 . -73) (16 . -73) 
    (17 . -73) (41 . -73) (44 . -73)) ((17 . 89) (16 . 90) (15 . 91) (14 . 92)
    (13 . 93) (12 . 94) (11 . 95) (10 . 96) (47 . -70) (6 . -70) (40 . -70) (
    18 . -70) (19 . -70) (23 . -70) (22 . -70) (21 . -70) (20 . -70) (24 . -70
    ) (25 . -70) (26 . -70) (27 . -70) (28 . -70) (41 . -70) (44 . -70)) ((19 
    . 87) (18 . 88) (40 . -65) (6 . -65) (47 . -65) (28 . -65) (27 . -65) (26 
    . -65) (25 . -65) (24 . -65) (20 . -65) (21 . -65) (22 . -65) (23 . -65) (
    41 . -65) (44 . -65)) ((23 . 83) (22 . 84) (21 . 85) (20 . 86) (47 . -62) 
    (6 . -62) (40 . -62) (24 . -62) (25 . -62) (26 . -62) (27 . -62) (28 . -62
    ) (41 . -62) (44 . -62)) ((25 . 81) (24 . 82) (40 . -60) (6 . -60) (47 . 
    -60) (28 . -60) (27 . -60) (26 . -60) (41 . -60) (44 . -60)) ((26 . 80) (
    47 . -58) (6 . -58) (40 . -58) (27 . -58) (28 . -58) (41 . -58) (44 . -58)
    ) ((27 . 79) (40 . -56) (6 . -56) (47 . -56) (28 . -56) (41 . -56) (44 . 
    -56)) ((40 . 2) (6 . 3) (47 . 4) (74 . 78) (28 . 75)) ((28 . 75) (40 . 2) 
    (6 . 3) (47 . 4) (74 . 77)) ((28 . 75) (40 . 2) (6 . 3) (47 . 4) (74 . 76)
    ) ((1 . -38) (40 . -38) (6 . -38) (47 . -38) (5 . -38) (31 . -38) (32 . 
    -38) (33 . -38) (35 . -38) (37 . -38) (38 . -38) (39 . -38) (45 . -38) (48
    . -38) (36 . -38) (30 . -38) (49 . -38) (46 . -38) (29 . -38) (34 . -38))
    ((40 . -46) (6 . -46) (47 . -46) (5 . -46)) ((40 . 2) (6 . 3) (47 . 4) (
    74 . 73) (5 . 1) (75 . 74)) ((5 . 1) (75 . 71) (76 . 72)) ((42 . 69) (43 
    . 70)) ((5 . 1) (75 . 71) (76 . 164) (41 . 165)) ((5 . 1) (75 . 163)) ((44
    . -20) (40 . -20) (41 . -20)) ((40 . 161) (44 . 162)) ((1 . -39) (40 . 
    -39) (6 . -39) (47 . -39) (5 . -39) (31 . -39) (32 . -39) (33 . -39) (35 
    . -39) (37 . -39) (38 . -39) (39 . -39) (45 . -39) (48 . -39) (36 . -39) (
    30 . -39) (49 . -39) (46 . -39) (29 . -39) (34 . -39)) ((40 . -47) (6 . 
    -47) (47 . -47) (5 . -47)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (
    42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 
    52) (56 . 53) (57 . 54) (58 . 55) (59 . 56) (60 . 57) (61 . 58) (62 . 59) 
    (63 . 160)) ((66 . 159) (34 . -50) (48 . -50) (29 . -50)) ((5 . 1) (40 . 2
    ) (6 . 3) (47 . 4) (31 . 5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 11) 
    (37 . 12) (38 . 13) (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 
    . 20) (72 . 21) (73 . 23) (86 . 158)) ((5 . 1) (40 . 2) (6 . 3) (47 . 4) (
    31 . 5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13) 
    (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 20) (72 . 21) (73 
    . 23) (86 . 157)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) 
    (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 
    . 53) (57 . 54) (58 . 55) (59 . 56) (60 . 57) (61 . 58) (62 . 156)) ((2 . 
    41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 
    . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 55)
    (59 . 56) (60 . 57) (61 . 155)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 
    . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51)
    (18 . 52) (56 . 53) (57 . 54) (58 . 55) (59 . 56) (60 . 154)) ((2 . 41) (
    3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48)
    (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 55) (59 
    . 56) (60 . 153)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) 
    (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 
    . 53) (57 . 54) (58 . 55) (59 . 152)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) 
    (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 
    . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 55) (59 . 151)) ((2 . 41) (3 . 
    42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55
    . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 55) (59 . 
    150)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (
    54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 
    54) (58 . 55) (59 . 149)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (
    42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 
    52) (56 . 53) (57 . 54) (58 . 148)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (
    45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 
    51) (18 . 52) (56 . 53) (57 . 54) (58 . 147)) ((2 . 41) (3 . 42) (4 . 43) 
    (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 
    50) (19 . 51) (18 . 52) (56 . 53) (57 . 146)) ((2 . 41) (3 . 42) (4 . 43) 
    (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 
    50) (19 . 51) (18 . 52) (56 . 53) (57 . 145)) ((2 . 41) (3 . 42) (4 . 43) 
    (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 
    50) (19 . 51) (18 . 52) (56 . 53) (57 . 144)) ((2 . 41) (3 . 42) (4 . 43) 
    (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 
    50) (19 . 51) (18 . 52) (56 . 53) (57 . 143)) ((2 . 41) (3 . 42) (4 . 43) 
    (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 
    50) (19 . 51) (18 . 52) (56 . 53) (57 . 142)) ((2 . 41) (3 . 42) (4 . 43) 
    (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 
    50) (19 . 51) (18 . 52) (56 . 53) (57 . 141)) ((2 . 41) (3 . 42) (4 . 43) 
    (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 
    50) (19 . 51) (18 . 52) (56 . 53) (57 . 140)) ((2 . 41) (3 . 42) (4 . 43) 
    (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 
    50) (19 . 51) (18 . 52) (56 . 53) (57 . 139)) ((40 . -88) (6 . -88) (47 . 
    -88) (28 . -88) (27 . -88) (26 . -88) (25 . -88) (24 . -88) (20 . -88) (21
    . -88) (22 . -88) (23 . -88) (19 . -88) (18 . -88) (10 . -88) (11 . -88) 
    (12 . -88) (13 . -88) (14 . -88) (15 . -88) (16 . -88) (17 . -88) (7 . -88
    ) (8 . -88) (41 . -88) (44 . -88)) ((40 . -89) (6 . -89) (47 . -89) (28 . 
    -89) (27 . -89) (26 . -89) (25 . -89) (24 . -89) (20 . -89) (21 . -89) (22
    . -89) (23 . -89) (19 . -89) (18 . -89) (10 . -89) (11 . -89) (12 . -89) 
    (13 . -89) (14 . -89) (15 . -89) (16 . -89) (17 . -89) (7 . -89) (8 . -89)
    (41 . -89) (44 . -89)) ((8 . 97) (7 . 98) (47 . -83) (6 . -83) (40 . -83)
    (17 . -83) (16 . -83) (15 . -83) (14 . -83) (13 . -83) (12 . -83) (11 . 
    -83) (10 . -83) (18 . -83) (19 . -83) (23 . -83) (22 . -83) (21 . -83) (20
    . -83) (24 . -83) (25 . -83) (26 . -83) (27 . -83) (28 . -83) (41 . -83) 
    (44 . -83)) ((8 . 97) (7 . 98) (47 . -84) (6 . -84) (40 . -84) (17 . -84) 
    (16 . -84) (15 . -84) (14 . -84) (13 . -84) (12 . -84) (11 . -84) (10 . 
    -84) (18 . -84) (19 . -84) (23 . -84) (22 . -84) (21 . -84) (20 . -84) (24
    . -84) (25 . -84) (26 . -84) (27 . -84) (28 . -84) (41 . -84) (44 . -84))
    ((8 . 97) (7 . 98) (47 . -85) (6 . -85) (40 . -85) (17 . -85) (16 . -85) 
    (15 . -85) (14 . -85) (13 . -85) (12 . -85) (11 . -85) (10 . -85) (18 . 
    -85) (19 . -85) (23 . -85) (22 . -85) (21 . -85) (20 . -85) (24 . -85) (25
    . -85) (26 . -85) (27 . -85) (28 . -85) (41 . -85) (44 . -85)) ((2 . 41) 
    (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48
    ) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 55) (59
    . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60) (28 . 113) (69 . 114) (71 
    . 138)) ((41 . 137) (28 . 75)) ((47 . -94) (6 . -94) (40 . -94) (8 . -94) 
    (7 . -94) (17 . -94) (16 . -94) (15 . -94) (14 . -94) (13 . -94) (12 . -94
    ) (11 . -94) (10 . -94) (18 . -94) (19 . -94) (23 . -94) (22 . -94) (21 . 
    -94) (20 . -94) (24 . -94) (25 . -94) (26 . -94) (27 . -94) (28 . -94) (41
    . -94) (44 . -94)) ((28 . 75) (44 . -100) (40 . -100) (6 . -100) (47 . 
    -100)) ((40 . 136) (44 . -96) (47 . -96) (6 . -96)) ((44 . 132) (47 . 133)
    (6 . 134) (50 . 135)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 
    . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52)
    (56 . 53) (57 . 54) (58 . 55) (59 . 56) (60 . 57) (61 . 58) (62 . 59) (63
    . 60) (69 . 131)) ((5 . 1) (75 . 37) (70 . 130)) ((43 . 129)) ((2 . 41) (
    3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48)
    (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 55) (59 
    . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60) (28 . 113) (69 . 114) (71 . 
    128)) ((40 . 2) (6 . 3) (47 . 4) (74 . 127) (28 . 75)) ((41 . -53) (40 . 
    -53)) ((28 . 75) (41 . -52) (40 . -52)) ((40 . 125) (41 . 126)) ((47 . 124
    )) ((1 . -104) (48 . -104) (40 . -104) (6 . -104) (47 . -104) (5 . -104) (
    31 . -104) (32 . -104) (33 . -104) (35 . -104) (37 . -104) (38 . -104) (39
    . -104) (45 . -104) (46 . -104) (49 . -104)) ((40 . -102) (6 . -102) (47 
    . -102) (46 . -102) (49 . -102)) ((40 . 2) (6 . 3) (47 . 4) (74 . 123) (46
    . -9) (49 . -9)) ((46 . -6) (49 . -6)) ((48 . 31) (81 . 122) (5 . 1) (40 
    . 2) (6 . 3) (47 . 4) (31 . 5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 
    11) (37 . 12) (38 . 13) (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) 
    (82 . 20) (72 . 21) (73 . 28) (49 . -8) (46 . -8)) ((46 . -5) (49 . -5)) (
    (40 . -103) (6 . -103) (47 . -103) (46 . -103) (49 . -103)) ((1 . -105) (
    48 . -105) (40 . -105) (6 . -105) (47 . -105) (5 . -105) (31 . -105) (32 
    . -105) (33 . -105) (35 . -105) (37 . -105) (38 . -105) (39 . -105) (45 . 
    -105) (46 . -105) (49 . -105)) ((28 . 186) (2 . 41) (3 . 42) (4 . 43) (5 
    . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) 
    (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 . 55) (59 . 56) (60 . 57) (61 
    . 58) (62 . 59) (63 . 60) (69 . 187)) ((40 . 2) (6 . 3) (47 . 4) (74 . 185
    ) (43 . -43)) ((1 . -28) (40 . -28) (6 . -28) (47 . -28) (5 . -28) (31 . 
    -28) (32 . -28) (33 . -28) (35 . -28) (37 . -28) (38 . -28) (39 . -28) (45
    . -28) (48 . -28) (36 . -28) (30 . -28) (49 . -28) (46 . -28) (29 . -28) 
    (34 . -28)) ((41 . 184) (40 . 125)) ((5 . 1) (75 . 183)) ((44 . -41) (40 
    . -41)) ((40 . 2) (6 . 3) (47 . 4) (74 . 182) (28 . 75)) ((47 . -95) (6 . 
    -95) (40 . -95) (8 . -95) (7 . -95) (17 . -95) (16 . -95) (15 . -95) (14 
    . -95) (13 . -95) (12 . -95) (11 . -95) (10 . -95) (18 . -95) (19 . -95) (
    23 . -95) (22 . -95) (21 . -95) (20 . -95) (24 . -95) (25 . -95) (26 . -95
    ) (27 . -95) (28 . -95) (41 . -95) (44 . -95)) ((3 . -99) (4 . -99) (2 . 
    -99) (45 . -99) (42 . -99) (5 . -99) (9 . -99) (19 . -99) (18 . -99)) ((3 
    . -98) (4 . -98) (2 . -98) (45 . -98) (42 . -98) (5 . -98) (9 . -98) (19 
    . -98) (18 . -98)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45)
    (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 
    . 53) (57 . 54) (58 . 55) (59 . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60
    ) (69 . 105) (51 . 181)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42
    . 45) (53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52
    ) (56 . 53) (57 . 54) (58 . 55) (59 . 56) (60 . 57) (61 . 58) (62 . 59) (
    63 . 60) (69 . 180)) ((47 . -93) (6 . -93) (40 . -93) (8 . -93) (7 . -93) 
    (17 . -93) (16 . -93) (15 . -93) (14 . -93) (13 . -93) (12 . -93) (11 . 
    -93) (10 . -93) (18 . -93) (19 . -93) (23 . -93) (22 . -93) (21 . -93) (20
    . -93) (24 . -93) (25 . -93) (26 . -93) (27 . -93) (28 . -93) (41 . -93) 
    (44 . -93)) ((41 . 179) (40 . 125)) ((40 . -81) (6 . -81) (47 . -81) (28 
    . -81) (27 . -81) (26 . -81) (25 . -81) (24 . -81) (20 . -81) (21 . -81) (
    22 . -81) (23 . -81) (19 . -81) (18 . -81) (10 . -81) (11 . -81) (12 . -81
    ) (13 . -81) (14 . -81) (15 . -81) (16 . -81) (17 . -81) (41 . -81) (44 . 
    -81)) ((40 . -80) (6 . -80) (47 . -80) (28 . -80) (27 . -80) (26 . -80) (
    25 . -80) (24 . -80) (20 . -80) (21 . -80) (22 . -80) (23 . -80) (19 . -80
    ) (18 . -80) (10 . -80) (11 . -80) (12 . -80) (13 . -80) (14 . -80) (15 . 
    -80) (16 . -80) (17 . -80) (41 . -80) (44 . -80)) ((40 . -79) (6 . -79) (
    47 . -79) (28 . -79) (27 . -79) (26 . -79) (25 . -79) (24 . -79) (20 . -79
    ) (21 . -79) (22 . -79) (23 . -79) (19 . -79) (18 . -79) (10 . -79) (11 . 
    -79) (12 . -79) (13 . -79) (14 . -79) (15 . -79) (16 . -79) (17 . -79) (41
    . -79) (44 . -79)) ((40 . -78) (6 . -78) (47 . -78) (28 . -78) (27 . -78)
    (26 . -78) (25 . -78) (24 . -78) (20 . -78) (21 . -78) (22 . -78) (23 . 
    -78) (19 . -78) (18 . -78) (10 . -78) (11 . -78) (12 . -78) (13 . -78) (14
    . -78) (15 . -78) (16 . -78) (17 . -78) (41 . -78) (44 . -78)) ((40 . -77
    ) (6 . -77) (47 . -77) (28 . -77) (27 . -77) (26 . -77) (25 . -77) (24 . 
    -77) (20 . -77) (21 . -77) (22 . -77) (23 . -77) (19 . -77) (18 . -77) (10
    . -77) (11 . -77) (12 . -77) (13 . -77) (14 . -77) (15 . -77) (16 . -77) 
    (17 . -77) (41 . -77) (44 . -77)) ((40 . -76) (6 . -76) (47 . -76) (28 . 
    -76) (27 . -76) (26 . -76) (25 . -76) (24 . -76) (20 . -76) (21 . -76) (22
    . -76) (23 . -76) (19 . -76) (18 . -76) (10 . -76) (11 . -76) (12 . -76) 
    (13 . -76) (14 . -76) (15 . -76) (16 . -76) (17 . -76) (41 . -76) (44 . 
    -76)) ((40 . -75) (6 . -75) (47 . -75) (28 . -75) (27 . -75) (26 . -75) (
    25 . -75) (24 . -75) (20 . -75) (21 . -75) (22 . -75) (23 . -75) (19 . -75
    ) (18 . -75) (10 . -75) (11 . -75) (12 . -75) (13 . -75) (14 . -75) (15 . 
    -75) (16 . -75) (17 . -75) (41 . -75) (44 . -75)) ((40 . -74) (6 . -74) (
    47 . -74) (28 . -74) (27 . -74) (26 . -74) (25 . -74) (24 . -74) (20 . -74
    ) (21 . -74) (22 . -74) (23 . -74) (19 . -74) (18 . -74) (10 . -74) (11 . 
    -74) (12 . -74) (13 . -74) (14 . -74) (15 . -74) (16 . -74) (17 . -74) (41
    . -74) (44 . -74)) ((17 . 89) (16 . 90) (15 . 91) (14 . 92) (13 . 93) (12
    . 94) (11 . 95) (10 . 96) (47 . -72) (6 . -72) (40 . -72) (18 . -72) (19 
    . -72) (23 . -72) (22 . -72) (21 . -72) (20 . -72) (24 . -72) (25 . -72) (
    26 . -72) (27 . -72) (28 . -72) (41 . -72) (44 . -72)) ((17 . 89) (16 . 90
    ) (15 . 91) (14 . 92) (13 . 93) (12 . 94) (11 . 95) (10 . 96) (47 . -71) (
    6 . -71) (40 . -71) (18 . -71) (19 . -71) (23 . -71) (22 . -71) (21 . -71)
    (20 . -71) (24 . -71) (25 . -71) (26 . -71) (27 . -71) (28 . -71) (41 . 
    -71) (44 . -71)) ((19 . 87) (18 . 88) (40 . -69) (6 . -69) (47 . -69) (28 
    . -69) (27 . -69) (26 . -69) (25 . -69) (24 . -69) (20 . -69) (21 . -69) (
    22 . -69) (23 . -69) (41 . -69) (44 . -69)) ((19 . 87) (18 . 88) (40 . -68
    ) (6 . -68) (47 . -68) (28 . -68) (27 . -68) (26 . -68) (25 . -68) (24 . 
    -68) (20 . -68) (21 . -68) (22 . -68) (23 . -68) (41 . -68) (44 . -68)) ((
    19 . 87) (18 . 88) (40 . -67) (6 . -67) (47 . -67) (28 . -67) (27 . -67) (
    26 . -67) (25 . -67) (24 . -67) (20 . -67) (21 . -67) (22 . -67) (23 . -67
    ) (41 . -67) (44 . -67)) ((19 . 87) (18 . 88) (40 . -66) (6 . -66) (47 . 
    -66) (28 . -66) (27 . -66) (26 . -66) (25 . -66) (24 . -66) (20 . -66) (21
    . -66) (22 . -66) (23 . -66) (41 . -66) (44 . -66)) ((23 . 83) (22 . 84) 
    (21 . 85) (20 . 86) (47 . -64) (6 . -64) (40 . -64) (24 . -64) (25 . -64) 
    (26 . -64) (27 . -64) (28 . -64) (41 . -64) (44 . -64)) ((23 . 83) (22 . 
    84) (21 . 85) (20 . 86) (47 . -63) (6 . -63) (40 . -63) (24 . -63) (25 . 
    -63) (26 . -63) (27 . -63) (28 . -63) (41 . -63) (44 . -63)) ((25 . 81) (
    24 . 82) (40 . -61) (6 . -61) (47 . -61) (28 . -61) (27 . -61) (26 . -61) 
    (41 . -61) (44 . -61)) ((26 . 80) (47 . -59) (6 . -59) (40 . -59) (27 . 
    -59) (28 . -59) (41 . -59) (44 . -59)) ((48 . 178) (5 . 1) (40 . 2) (6 . 3
    ) (47 . 4) (31 . 5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12
    ) (38 . 13) (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 20) (
    72 . 21) (73 . 28)) ((48 . 174) (5 . 1) (40 . 2) (6 . 3) (47 . 4) (31 . 5)
    (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13) (39 . 
    14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 20) (72 . 21) (73 . 28) 
    (36 . 175) (30 . 176) (67 . 177)) ((48 . 171) (29 . 172) (34 . 173)) ((27 
    . 79) (40 . -57) (6 . -57) (47 . -57) (28 . -57) (41 . -57) (44 . -57)) ((
    5 . 1) (75 . 170)) ((43 . 169)) ((42 . 168)) ((41 . 167) (40 . 161)) ((40 
    . 2) (6 . 3) (47 . 4) (74 . 166)) ((45 . -19) (39 . -19) (38 . -19) (37 . 
    -19) (35 . -19) (33 . -19) (32 . -19) (31 . -19) (5 . -19) (47 . -19) (6 
    . -19) (40 . -19) (48 . -19) (1 . -19) (46 . -19) (49 . -19)) ((40 . 2) (6
    . 3) (47 . 4) (74 . 202)) ((5 . 1) (75 . 71) (76 . 200) (41 . 201)) ((5 
    . 1) (75 . 199)) ((44 . -21) (40 . -21) (41 . -21)) ((40 . 2) (6 . 3) (47 
    . 4) (74 . 198)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (
    53 . 46) (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 
    53) (57 . 54) (58 . 55) (59 . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60) 
    (69 . 197)) ((40 . 2) (6 . 3) (47 . 4) (74 . 196)) ((40 . 2) (6 . 3) (47 
    . 4) (74 . 195)) ((5 . 1) (40 . 2) (6 . 3) (47 . 4) (31 . 5) (32 . 6) (1 
    . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13) (39 . 14) (45 . 15) 
    (70 . 16) (75 . 17) (74 . 18) (82 . 20) (72 . 21) (73 . 23) (86 . 194)) ((
    2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) 
    (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 
    . 55) (59 . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60) (69 . 193)) ((36 
    . 191) (30 . 192)) ((40 . 2) (6 . 3) (47 . 4) (74 . 190)) ((40 . -87) (6 
    . -87) (47 . -87) (28 . -87) (27 . -87) (26 . -87) (25 . -87) (24 . -87) (
    20 . -87) (21 . -87) (22 . -87) (23 . -87) (19 . -87) (18 . -87) (10 . -87
    ) (11 . -87) (12 . -87) (13 . -87) (14 . -87) (15 . -87) (16 . -87) (17 . 
    -87) (7 . -87) (8 . -87) (41 . -87) (44 . -87)) ((28 . 75) (44 . -101) (40
    . -101) (6 . -101) (47 . -101)) ((40 . 136) (44 . -97) (47 . -97) (6 . 
    -97)) ((5 . 1) (40 . 2) (6 . 3) (47 . 4) (31 . 5) (32 . 6) (1 . 8) (65 . 9
    ) (33 . 10) (35 . 11) (37 . 12) (38 . 13) (39 . 14) (45 . 15) (70 . 16) (
    75 . 17) (74 . 18) (82 . 20) (72 . 21) (73 . 23) (86 . 189)) ((42 . 188)) 
    ((44 . -43) (40 . -43)) ((1 . -27) (40 . -27) (6 . -27) (47 . -27) (5 . 
    -27) (31 . -27) (32 . -27) (33 . -27) (35 . -27) (37 . -27) (38 . -27) (39
    . -27) (45 . -27) (48 . -27) (36 . -27) (30 . -27) (49 . -27) (46 . -27) 
    (29 . -27) (34 . -27)) ((41 . -55) (40 . -55)) ((28 . 75) (41 . -54) (40 
    . -54)) ((2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) 
    (54 . 47) (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 
    . 54) (58 . 55) (59 . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60) (28 . 
    113) (69 . 114) (71 . 213) (41 . 214)) ((48 . 212) (5 . 1) (40 . 2) (6 . 3
    ) (47 . 4) (31 . 5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12
    ) (38 . 13) (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 20) (
    72 . 21) (73 . 28)) ((1 . -32) (40 . -32) (6 . -32) (47 . -32) (5 . -32) (
    31 . -32) (32 . -32) (33 . -32) (35 . -32) (37 . -32) (38 . -32) (39 . -32
    ) (45 . -32) (48 . -32) (36 . -32) (30 . -32) (49 . -32) (46 . -32) (29 . 
    -32) (34 . -32)) ((5 . 1) (40 . 2) (6 . 3) (47 . 4) (31 . 5) (32 . 6) (1 
    . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13) (39 . 14) (45 . 15) 
    (70 . 16) (75 . 17) (74 . 18) (82 . 20) (72 . 21) (73 . 23) (86 . 211)) ((
    2 . 41) (3 . 42) (4 . 43) (5 . 1) (45 . 44) (42 . 45) (53 . 46) (54 . 47) 
    (75 . 48) (55 . 49) (9 . 50) (19 . 51) (18 . 52) (56 . 53) (57 . 54) (58 
    . 55) (59 . 56) (60 . 57) (61 . 58) (62 . 59) (63 . 60) (69 . 210)) ((40 
    . 2) (6 . 3) (47 . 4) (74 . 209) (28 . 75)) ((48 . 208) (5 . 1) (40 . 2) (
    6 . 3) (47 . 4) (31 . 5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37
    . 12) (38 . 13) (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 
    20) (72 . 21) (73 . 28)) ((1 . -35) (40 . -35) (6 . -35) (47 . -35) (5 . 
    -35) (31 . -35) (32 . -35) (33 . -35) (35 . -35) (37 . -35) (38 . -35) (39
    . -35) (45 . -35) (48 . -35) (36 . -35) (30 . -35) (49 . -35) (46 . -35) 
    (29 . -35) (34 . -35)) ((5 . 1) (40 . 2) (6 . 3) (47 . 4) (31 . 5) (32 . 6
    ) (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13) (39 . 14) (45 
    . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 20) (72 . 21) (73 . 23) (86 . 
    207)) ((40 . 2) (6 . 3) (47 . 4) (74 . 206) (28 . 75)) ((1 . -37) (40 . 
    -37) (6 . -37) (47 . -37) (5 . -37) (31 . -37) (32 . -37) (33 . -37) (35 
    . -37) (37 . -37) (38 . -37) (39 . -37) (45 . -37) (48 . -37) (36 . -37) (
    30 . -37) (49 . -37) (46 . -37) (29 . -37) (34 . -37)) ((42 . 205)) ((41 
    . 204) (40 . 161)) ((40 . 2) (6 . 3) (47 . 4) (74 . 203)) ((45 . -18) (39 
    . -18) (38 . -18) (37 . -18) (35 . -18) (33 . -18) (32 . -18) (31 . -18) (
    5 . -18) (47 . -18) (6 . -18) (40 . -18) (48 . -18) (1 . -18) (46 . -18) (
    49 . -18)) ((45 . -17) (39 . -17) (38 . -17) (37 . -17) (35 . -17) (33 . 
    -17) (32 . -17) (31 . -17) (5 . -17) (47 . -17) (6 . -17) (40 . -17) (48 
    . -17) (1 . -17) (46 . -17) (49 . -17)) ((40 . 2) (6 . 3) (47 . 4) (74 . 
    226)) ((5 . 1) (75 . 71) (76 . 224) (41 . 225)) ((5 . 1) (40 . 2) (6 . 3) 
    (47 . 4) (31 . 5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12) 
    (38 . 13) (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 20) (72 
    . 21) (73 . 23) (86 . 223)) ((48 . 222) (5 . 1) (40 . 2) (6 . 3) (47 . 4) 
    (31 . 5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13)
    (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 20) (72 . 21) (73
    . 28)) ((40 . 2) (6 . 3) (47 . 4) (74 . 221)) ((5 . 1) (40 . 2) (6 . 3) (
    47 . 4) (31 . 5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12) (
    38 . 13) (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 20) (72 
    . 21) (73 . 23) (86 . 220)) ((40 . 2) (6 . 3) (47 . 4) (74 . 219) (28 . 75
    )) ((48 . 218) (5 . 1) (40 . 2) (6 . 3) (47 . 4) (31 . 5) (32 . 6) (1 . 8)
    (65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13) (39 . 14) (45 . 15) (70 
    . 16) (75 . 17) (74 . 18) (82 . 20) (72 . 21) (73 . 28)) ((40 . 2) (6 . 3)
    (47 . 4) (74 . 217)) ((41 . 216) (40 . 125)) ((40 . 2) (6 . 3) (47 . 4) (
    74 . 215)) ((1 . -29) (40 . -29) (6 . -29) (47 . -29) (5 . -29) (31 . -29)
    (32 . -29) (33 . -29) (35 . -29) (37 . -29) (38 . -29) (39 . -29) (45 . 
    -29) (48 . -29) (36 . -29) (30 . -29) (49 . -29) (46 . -29) (29 . -29) (34
    . -29)) ((40 . 2) (6 . 3) (47 . 4) (74 . 232)) ((1 . -31) (40 . -31) (6 
    . -31) (47 . -31) (5 . -31) (31 . -31) (32 . -31) (33 . -31) (35 . -31) (
    37 . -31) (38 . -31) (39 . -31) (45 . -31) (48 . -31) (36 . -31) (30 . -31
    ) (49 . -31) (46 . -31) (29 . -31) (34 . -31)) ((40 . 2) (6 . 3) (47 . 4) 
    (74 . 231)) ((5 . 1) (40 . 2) (6 . 3) (47 . 4) (31 . 5) (32 . 6) (1 . 8) (
    65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13) (39 . 14) (45 . 15) (70 . 
    16) (75 . 17) (74 . 18) (82 . 20) (72 . 21) (73 . 23) (86 . 230)) ((5 . 1)
    (40 . 2) (6 . 3) (47 . 4) (31 . 5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (
    35 . 11) (37 . 12) (38 . 13) (39 . 14) (45 . 15) (70 . 16) (75 . 17) (74 
    . 18) (82 . 20) (72 . 21) (73 . 28) (36 . -48) (30 . -48)) ((1 . -34) (40 
    . -34) (6 . -34) (47 . -34) (5 . -34) (31 . -34) (32 . -34) (33 . -34) (35
    . -34) (37 . -34) (38 . -34) (39 . -34) (45 . -34) (48 . -34) (36 . -34) 
    (30 . -34) (49 . -34) (46 . -34) (29 . -34) (34 . -34)) ((40 . 2) (6 . 3) 
    (47 . 4) (74 . 229)) ((5 . 1) (40 . 2) (6 . 3) (47 . 4) (31 . 5) (32 . 6) 
    (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13) (39 . 14) (45 . 
    15) (70 . 16) (75 . 17) (74 . 18) (82 . 20) (72 . 21) (73 . 28) (48 . -51)
    (29 . -51) (34 . -51)) ((41 . 228) (40 . 161)) ((40 . 2) (6 . 3) (47 . 4)
    (74 . 227)) ((45 . -16) (39 . -16) (38 . -16) (37 . -16) (35 . -16) (33 
    . -16) (32 . -16) (31 . -16) (5 . -16) (47 . -16) (6 . -16) (40 . -16) (48
    . -16) (1 . -16) (46 . -16) (49 . -16)) ((45 . -15) (39 . -15) (38 . -15)
    (37 . -15) (35 . -15) (33 . -15) (32 . -15) (31 . -15) (5 . -15) (47 . 
    -15) (6 . -15) (40 . -15) (48 . -15) (1 . -15) (46 . -15) (49 . -15)) ((40
    . 2) (6 . 3) (47 . 4) (74 . 233)) ((1 . -36) (40 . -36) (6 . -36) (47 . 
    -36) (5 . -36) (31 . -36) (32 . -36) (33 . -36) (35 . -36) (37 . -36) (38 
    . -36) (39 . -36) (45 . -36) (48 . -36) (36 . -36) (30 . -36) (49 . -36) (
    46 . -36) (29 . -36) (34 . -36)) ((5 . 1) (40 . 2) (6 . 3) (47 . 4) (31 . 
    5) (32 . 6) (1 . 8) (65 . 9) (33 . 10) (35 . 11) (37 . 12) (38 . 13) (39 
    . 14) (45 . 15) (70 . 16) (75 . 17) (74 . 18) (82 . 20) (72 . 21) (73 . 28
    ) (36 . -49) (30 . -49)) ((1 . -33) (40 . -33) (6 . -33) (47 . -33) (5 . 
    -33) (31 . -33) (32 . -33) (33 . -33) (35 . -33) (37 . -33) (38 . -33) (39
    . -33) (45 . -33) (48 . -33) (36 . -33) (30 . -33) (49 . -33) (46 . -33) 
    (29 . -33) (34 . -33)) ((1 . -30) (40 . -30) (6 . -30) (47 . -30) (5 . -30
    ) (31 . -30) (32 . -30) (33 . -30) (35 . -30) (37 . -30) (38 . -30) (39 . 
    -30) (45 . -30) (48 . -30) (36 . -30) (30 . -30) (49 . -30) (46 . -30) (29
    . -30) (34 . -30)) ((45 . -14) (39 . -14) (38 . -14) (37 . -14) (35 . -14
    ) (33 . -14) (32 . -14) (31 . -14) (5 . -14) (47 . -14) (6 . -14) (40 . 
    -14) (48 . -14) (1 . -14) (46 . -14) (49 . -14))))

(define rto-v
  #(#f 87 87 85 85 84 84 84 81 81 83 83 77 77 79 79 79 79 79 79 76 76 86 86 
    73 73 82 82 82 82 82 82 82 82 82 82 82 82 82 82 68 68 70 70 65 65 64 64 67
    67 66 66 71 71 71 71 69 69 63 63 62 62 61 61 61 60 60 60 60 60 59 59 59 
    58 58 58 58 58 58 58 58 58 57 57 57 57 56 56 56 56 55 55 55 55 55 55 52 52
    50 50 51 51 80 80 78 78 74 74 74 75 54 54 53 72))

(define mtab
  '(($lone-comm . 1) ($string . 2) ($float . 3) ($fixed . 4) ($ident . 5) (
    ";" . 6) (".'" . 7) ("'" . 8) ("~" . 9) (".^" . 10) (".\\" . 11) ("./" . 
    12) (".*" . 13) ("^" . 14) ("\\" . 15) ("/" . 16) ("*" . 17) ("-" . 18) (
    "+" . 19) (">=" . 20) ("<=" . 21) (">" . 22) ("<" . 23) ("~=" . 24) ("==" 
    . 25) ("&" . 26) ("|" . 27) (":" . 28) ("case" . 29) ("elseif" . 30) (
    "clear" . 31) ("global" . 32) ("return" . 33) ("otherwise" . 34) ("switch"
    . 35) ("else" . 36) ("if" . 37) ("while" . 38) ("for" . 39) ("," . 40) (
    ")" . 41) ("(" . 42) ("=" . 43) ("]" . 44) ("[" . 45) ("function" . 46) (
    #\newline . 47) ("end" . 48) ($end . 49)))

;;; end tables
